# Examples

## Cases from [10.1093/pnasnexus/pgae005](https://doi.org/10.1093/pnasnexus/pgae005)

* Poisson equation in two dimensions: [`poisson`](poisson/)

* Velocity from tracer: [`velocity_from_tracer`](velocity_from_tracer/)

* Inferring conductivity from temperature: [`heat`](heat/)
